# UTF-8 encoded Bulgarian translation file for use with Oddmuse
#
# Copyright (c) 2004 Stanislav Traykov <stanislav@tortoises.org>
# Copyright (c) 2003, 2004  Alex Schröder <alex@emacswiki.org>
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was updated for Oddmuse 1.354.
#
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Не е разрешено четенето: блокиран потребител, IP адрес или мрежа.
Could not create %s
Не може да се създаде %s
Invalid UserName %s: not saved.
Невалидно потребителско име %s: нищо не бе записано.
UserName must be 50 characters or less: not saved
Дължината на потребителското име не трябва да надвишава 50 знака: нищо не бе записано.
XML::RSS is not available on this system.
Модулът XML::RSS не е инсталиран на тази система.
diff
разлики
history
стари версии
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

 . . . . 

Click to edit this page
Кликни тук, за да създадеш тази страница
Invalid action parameter %s
Невалидна команда: %s
Invalid URL.
Невалидно URL.
Page name is missing

Page name is too long: %s
Прекалено дълго име на страница: %s
Invalid Page %s
Невалидна страница: %s
Invalid Page %s (must not end with .db)
Невалидна страница: %s (не може да завършва на .db)
Invalid Page %s (must not end with .lck)
Невалидна страница: %s (не може да завършва на .lck)
Page name may not contain space characters: %s
Името на страницата не може да съдържа интервали: %s
Preview:
Предварителен преглед:
Preview only, not yet saved
Предварителен преглед, още не е записано
Please go on to %s.
Моля продължи на %s.
Could not open %s log file
Не може да се отвори лог-файла: %s
Error was
Грешката бе
Note: This error is normal if no changes have been made.
Забележка: Тази грешка е нормална, ако не са направени промени.
Could not open old %s log file
Не може да се отвори стария лог-файл: %s
No updates since %s
Няма промени от %s насам
Updates since %s
Промени от %s насам
Updates in the last %s days
Промени през последните %s дни
Updates in the last %s day
Промени през последния %s ден
for %s only
само за %s
List latest change per page only
Показвай само последната промяна на страниците
List all changes
Покажи всички промени
List only major changes
Покажи само съществените промени
Include minor changes
Покажи и малките промени
%s days
%s дни
List later changes
Покажи по-ранни промени
Filters
Филтри
Username:
Потребителско име:
Host:
Хост:
Language:
Език:
Go!
Хайде!
(minor)
(малка промяна)
rollback
връщане на стара весия
new

from %s
от %s
History of %s
История на %s
Compare
Сравни
Revision %s
Версия %s
by
от
Rolling back changes
Връщане на промените
Missing target for rollback.
Липсва дата, до която да се върне.
Target for rollback is too far back.
Датата за връщане е прекалено стара.
Rollback to %s
Връщане до %s
%s rolled back
Промените върху %s бяха успешно върнати
[Home]
[Начална страница]
redirected from %s
Препратка от %s
Click to search for references to this page
Търси споменавания на това заглавие
Cookie: 
Курабийка (Cookie): 
Warning
Предупреждение
Database is stored in temporary directory %s
Базатая данни се съхранява в %s
%s seconds
%s секунди
The same page on other sites:
Същата страница на други места:
EditNearLinks
Редакция на близки линкове
Last edited
Последна промяна
Edited
Променено
by %s
от %s
(diff)
(разлики)
Run maintenance

Unlock site

Lock site

Unlock page

Lock page

Comments on this page
Коментари към тази страница
Edit revision %s of this page
Редакция на версия %s на тази страница
Edit text of this page
Редакция на тази страница
e

This page is read-only
Тази страница е защитена от промени
View other revisions
Виж други версии
View current revision
Виж актуалната версия
View all changes
Виж всички промени
Back to %s
Обратно към %s
new comment
Нов коментар
s

Save
Запис
Preview
Предварителен преглед
Search:
Търси:
Replace:
Замести:
Validate HTML
Проверка на HTML
Validate CSS
Проверка на CSS
Difference (from revision %1 to %2)
Разлики (между версия %1 и %2)
revision %s
версия %s
current revision
актуална версия
Difference (from prior %s revision)
Разлики (с предишната %s ревизия)
major
съществена
minor
малка
No diff available.
Не са належащи данни за разликите.
Changed:
Заместено:
Removed:
Изтрито:
Added:
Прибавено:
to
с
Revision %s not available
Версия %s не е належаща
showing current revision instead
Вместо това, ето актуалната версия
Showing revision %s
Ето версия %s
Cannot save an nameless page.
Не може да се направи запис на безименна страница.
Cannot open %s
не може да се отвори: %s
Cannot write %s
Не може да се запише: %s
Could not get %s lock
Не може да се резервират изключителни права върху %s.
Unlocking
Премахване на защити
This operation may take several seconds...
Тази операция може да потрае малко...
Forced unlock of %s lock.
Принудително премахване на защитата на %s.
No unlock required.
Не е нужмно премахване на защити.
%s hours ago
преди %s часа
1 hour ago
преди един час
%s minutes ago
преди %s минути
1 minute ago
преди една минута
%s seconds ago
преди %s секунди
1 second ago
преди една секунда
just now
точно сега
Editing Denied
Редакцията не е разрешена
Editing not allowed: user, ip, or network is blocked.
Редакцията не е разрешена: блокиран потребител, IP адрес или мрежа.
Contact the wiki administrator for more information.
За повече информация се свържи с уики-администратора.
The rule %s matched for you.
Правило %s съответства.
See %s for more information.
Виж %s за повече информация.
Editing not allowed: %s is read-only.
Редакцията не е разрешена: %s е с защита от запис.
Only administrators can upload files.
Само администратори могат да качват файлове.
Editing revision %s of
Редакция на версия %s на
Editing %s
Редакция на %s
Editing old revision %s.
Редакция на стара версия %s.
Saving this page will replace the latest revision with this text.
Записът на тази страница ще замести последната версия с този текст.
Summary:
Резюме:
This change is a minor edit.
Това е малка промяна.
Replace this file with text.
Замени този файл с текст
Replace this text with a file.
Замени този текст с файл
File to upload: 
Файл за качване: 
Files of type %s are not allowed.
Файлове тип %s не са разрешени.
Password
Парола
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Паролата се записва в курабийка (cookie), ако те са разрешени. Курабийките могат да се загубят, ако се свързваш от друг компютър или акаунт, или с друг софтуер.
You are currently an administrator on this site.
Ти си администратор.
You are currently an editor on this site.
Ти си редактор.
You are a normal user on this site.
Ти си нормален потребител.
Your password does not match any of the  administrator or editor passwords.
Твоята парола не съвпада нито с администраторската, нито с редакторската парола.
Password:
Парола:
This site does not use admin or editor passwords.
Тази страница не използва администраторски или редакторски пароли.
This operation is restricted to site editors only...
Тази операция може да се извършва само от редактори.
This operation is restricted to administrators only...
Тази операция може да се извършва само от администратори.
Rule "%1" matched "%2" on this page.

Index of all pages
Индекс на всички страници
all pages
всички страници
permanent anchors
постоянни точки
near links
близки линкове
(for %s)
(за %s)
%s pages found.
%s намерени страници.
Replaced: %s
Заместено: %s
Search for: %s
Търси: %s
View changes for these pages
Промени на тези страници
Search sites on the %s as well
Също търси страници на %s
and
и
or
или
Fetching results from %s:
Набавям резултати от %s:
Near pages:
Близки страници:
last updated
последна промяна
Complete Content
Пълно съдържание
The main page is %s.
Главната страница е %s.
Editing not allowed for %s.
Редакция на %s не е разрешена.
SampleUndefinedPage
ПримерНаНедефиниранаСтраница
%s cannot be defined.
%s не може да се дефинира.
Sample_Undefined_Page
Пример_на_недефинирана_страница
[[%s]] cannot be defined.
[[%s]] не може да се дефинира.
Only an administrator can create %s.

Transfer Error: %s
Грешка при трансфера: %s
Browser reports no file info.
Браузъра не доставя информация за файла.
Browser reports no file type.
Браузъра не доставя вида на файла.
Edit Denied

The page contains banned text.

This page was changed by somebody else %s.
Страницата бе променена от друг (%s).
The changes conflict.  Please check the page again.
Промените се застъпват. Моля провери страницата още веднъж.
Please check whether you overwrote those changes.
Моля провери, дали няма конфликт между промените.
Anonymous
Анонимен
Could not get a lock to merge!
Не може да се придобият изключителни права за сливане!
you
ти
ancestor
предшественик
other
друг
Maintenance on all pages
Поддръжка на всички страници
Maintenance not done.
Поддъжката не бе осъществена.
(Maintenance can only be done once every 12 hours.)
(Поддръжка се прави веднъж на 12 часа.)
Remove the "maintain" file or wait.
Изтрий файла "maintain" или изчакай.
Main lock obtained.
Защита: придобиване на изключителни права.
Expiring keep files and deleting pages marked for deletion
Триене на стари версии и страници маркирани за триене.
not deleted: 

deleted
Файлът бе изтрит
Moving part of the %s log file.
Преместване на част от лог-файла %s.
Moving %s log entries.
Преместване на %s лог-записа.
Getting page index file for %s.
Получаване на индекс за %s.
Main lock released.
Премахване на защитата.
Set or Remove global edit lock
Налагане или отмяна на глобална защита от редакции.
Edit lock created.
Бе наложена защита от редакции.
Edit lock removed.
Защитата от редакции бе премахната.
Set or Remove page edit lock
Налагане или отмяна на защита от редакции.
Missing page id to lock/unlock...
Липсва идентификатор на страница за налагане/отмяна на защита...
Lock for %s created.
Бе наложена защита за %s.
Lock for %s removed.
Защитата за %s бе отменена.
Displaying Wiki Version
Показ на Уики-версия
Inter links:
Интер-линкове:
Near links:
Близки линкове:
Too many connections by %s
Прекалено много връзки с %s
Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

Recent Visitors
Скорошни посетители
Referrers
Линкове
All Referrers
Всички линкове
anchor first defined here: %s
Точката бе първо дефинирана тук: %s
Click to search for references to this permanent anchor
Кликни за търсене на връзки към тази постоянна точка
the page %s also exists

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Delete page

Rename this page to:

Cannot highlight the language %s.

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Footnotes:

image: %s

Index

Languages:

Show!

Define

Full Link List
Пълен списък на линковете
Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

Orphan List

Trail: 

None

Type

Permalink to "%s"

Portrait

Static Copy

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

The translation is up to date.

The translation is outdated.

The page does not exist.

http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
http://www.amazon.com/exec/obidos/ISBN=%s
http://www.amazon.com/exec/obidos/ISBN=%s
alternate
провери в амазон
http://www.pricescan.com/books/BookDetail.asp?isbn=%s
http://www.pricescan.com/books/BookDetail.asp?isbn=%s
search
търси
Blog

END_OF_TRANSLATION
